# Analysis of the impact of competitor size and ecotype on growth rate in guppies

#Load necessary libraries
library(bbmle)
library(tidyr)

setwd("~/Documents/Research/GuppyComp/Potter_JAE_guppy_competition") # Change this to the directory containing all files required for analysis

data <- read.csv("Potter_guppy_growth_data.csv", header=T)

source("Potter_growth_model_functions.R") # Load the functions for performing the analysis

sizeoffset <- 18 # Set the size offset when considering growth as change in standard lenfth  
sizeofset.mass<- 125 # Set size offset when growth is change in mass


# Dummy coding for ecotype
data$LP <- 0
data$HP <- 0
data[which(data$pheno=='LP'),'LP'] <- 1
data[which(data$pheno=='HP'),'HP'] <- 1

# growth
data$growth <- log(data$day28sl / data$initial.sl)
data$growth.mass <- log(data$day28mass / data$initial.mass)

#Choose which data to use
exp.data <- data
exp.data <- data[which(data$orig.rep=='O'),] # remove growth data from replacement fish

# Choose watershed: "Aripo", or "Quare"
exp.data <- exp.data[which(exp.data$drainage=='Aripo'),] 

# Choose which model form to use: TRUE = exponential model, FALSE = proportional model
exp.test<- FALSE 

# For each model, optimal starting values for each parameter were selected by cycling through a range of start values and selecting those which resulted in the lowest global log-likelihood score. 
n.starts <- 10 # Number of different starting values for each parameter
# Generate range of staring values
p.names <- c('b0LP','bzLP','bNLP','bz2LP',
             'b0HP','bzHP','bNHP', 'bz2HP',
             'philength','phistrat','philengthstrat',
             
             'sigma')
parameters <- array(0,c(5,length(p.names)))

start.values <- array(NA,c(n.starts,12))

start.values[,1] <- runif(n.starts, 0.1,1)
start.values[,2] <- runif(n.starts,0.1,2)
start.values[,3] <- runif(n.starts,-1,-0.1)
start.values[,4] <- runif(n.starts,0.1,1)

start.values[,5] <- runif(n.starts,0.1,1)
start.values[,6] <- runif(n.starts,0.1,2)
start.values[,7] <- runif(n.starts,-1,-0.1)
start.values[,8] <- runif(n.starts,0.1,1)

start.values[,9] <- runif(n.starts,0.1,1)
start.values[,10] <- runif(n.starts,-0.05,0.05)
start.values[,11] <- runif(n.starts,-0.05,0.05)
start.values[,12] <-runif(n.starts,0.1,2)


dimnames(start.values) <- list(c(1:n.starts),c('b0LP','bzLP','bNLP','bz2LP',
                                               'b0HP','bzHP','bNHP', 'bz2HP',
                                               'philength','phistrat','philengthstrat',
                                               'sigma'))

#Preallocate matrices to save results
logLikes <- array(NA,c(5,2))
dimnames(logLikes) <- list(c('model1','model2','model3','model4','model5'),c('logLike','AIC'))

#-----------------

# RUN MODELS
# Parameters can be dropped from the full model by fixing them at zero
# N.B. set bz2LP=0 for Quare analysis: we dropped this non-significant quadratic term in our final Quare model


# Model1: asymmetric between ecotypes, ecotypes differ in how competitive ability changes with size (full model)
fixed <- c(#bz2LP=0, 
                    ) 
fit1 <- fitdemo(start=start.values,n.starts=n.starts,sizeoffset=sizeoffset,fixed=fixed)
logLikes[1,] <- fit1[[4]]

# Model2: asymmetric between ecotypes, competitive ability changes with size in the same way between ecotypes
fixed <- c(# bz2LP=0,
              philengthstrat=0)
              
fit2 <- fitdemo(start=start.values,n.starts=n.starts,sizeoffset=sizeoffset,fixed=fixed)
logLikes[2,] <- fit2[[4]]

# Model3: competition is symmetric with regards to ecotype,  ecotypes differ in how competitive ability changes with size 
fixed <- c(#bz2LP=0,
              phistrat=0) 

fit3 <- fitdemo(start=start.values,n.starts=n.starts,sizeoffset=sizeoffset,fixed=fixed)
logLikes[3,] <- fit3[[4]]

# Model4: competition is symmetric with regards to ecotype, competitive ability changes with size in the same way between ecotypes
fixed <- c(#bz2LP=0,
              phistrat=0,
              philengthstrat=0)

fit4 <- fitdemo(start=start.values,n.starts=n.starts,sizeoffset=sizeoffset,fixed=fixed)
logLikes[4,] <- fit4[[4]]


#Model5: null model - competition is symmetric - there is no effect of size or ecotype on competitve ability
fixed <- c( #bz2LP=0, 
              phistrat=0,
              philength=0,
              philengthstrat=0)

fitnull <- fitdemo(start=start.values,n.starts=n.starts,sizeoffset=sizeoffset,fixed=fixed)
logLikes[5,] <- fitnull[[4]]

system('say bingo')

# Check which model provided the best fit

logLikes

# View parameter estimates for different model fits
fit1[2]
fit2[2]
fit3[2]
fit4[2]
fitnull[2]

# end of code
